import pandas as pd

import plotly.graph_objects as go

import read_data_sclab

Start_time = pd.datetime.now() - pd.Timedelta(days=3)
End_time = pd.datetime.now()

measurement_points = {35: 'NatWi', 111: 'ICT - air', 154: 'gravel roof I', 155: 'bitumen roof', 164: 'green roof', 165: 'gravel roof II', 166: 'brick', 167: 'stone paving', 170: 'short green', 171: 'long green', 156: 'green RG I', 157: 'green RG II', 158: 'tree I' , 159: 'tree II', 104: 'solar radiation', 53: 'rain', 114: 'relative humidity'}

fig = go.Figure()

for number, name in measurement_points.items():
    sensor_data = read_data_sclab.read_sensors(number, Start_time, End_time)
    if number == 104:
        fig.add_trace(go.Scatter(x=sensor_data.index, y=sensor_data.values, fill='tozeroy', line_color = 'grey', fillcolor = 'rgba(170, 170, 170, 0.5)', name = name, yaxis='y2'))
    elif number == 53:
        fig.add_trace(go.Scatter(x=sensor_data.index, y=sensor_data.values, line_color='rgba(60,150,255)', name = name, yaxis='y3'))
    elif number == 114:
        fig.add_trace(go.Scatter(x=sensor_data.index, y=sensor_data.values, mode='lines', name = name, yaxis='y4'))
    else:
        fig.add_trace(go.Scatter(x=sensor_data.index, y=sensor_data.values, mode='lines', name = name))

 
fig.update_layout(font=dict(family="Times New Roman", size=12), xaxis=dict(title='date', range=[Start_time, End_time], domain=[0.06, 0.90]), yaxis=dict(title='temperature (°C)', range=[0,100]), yaxis2=dict(title='solar radiation (W/m\u00b2)',side='left', position=0.03, range=[0,1000], anchor="free", overlaying="y", showgrid=False), yaxis3=dict(title='rain (mm/min)',side='right', range=[0,5], anchor="x", overlaying="y", showgrid=False), yaxis4=dict(title='relative humidity (%)',side='right', position=0.94, range=[0,100], anchor="free", overlaying="y", showgrid=False))

fig.write_html('temperature_campus.html')

fig.show()